# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2012 Cole Kendrick colej.kendrick@gmail.com Alexander Kendrick kentalex8@gmail.com
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import locale, os, time

from gi.repository import Gtk, Gio, Gdk # pylint: disable=E0611
from gi.repository.GdkPixbuf import Pixbuf
import logging
logger = logging.getLogger('pictoric')

TEXTDOMAIN = 'pictoric'
LOCALEDIR = '/opt/extras.ubuntu.com/pictoric/share/locale'
from locale import gettext as _
locale.bindtextdomain(TEXTDOMAIN, LOCALEDIR)
locale.textdomain(TEXTDOMAIN)

from pictoric_lib import Window

class PictoricWindow(Window):
    __gtype_name__ = "PictoricWindow"
    SCHEMA = 'org.gnome.desktop.background'
    KEY = 'picture-uri'
    minute=60
    defaultDirectory = '/home/%s/Pictures' % (os.environ['USER'])
    defaultInterval = minute*5  
    sourceFolder = defaultDirectory
    iconStore = Gtk.ListStore(Pixbuf)
    
    def finish_initializing(self, builder, sourceFolder=defaultDirectory, sourceInterval=defaultInterval, configPath ='/home/%s/.config/pictoric/pictoric.conf' % (os.environ['USER']), minute=60): # pylint: disable=E1002
        """Set up the main window"""
        # self.set_default_size(400,500)
        autofile = '/home/%s/.config/autostart/pictoric.desktop' % (os.environ['USER'])
        confdir = '/home/%s/.config/pictoric/' % (os.environ['USER'])
        runfile = '/home/%s/.config/pictoric/run_pictoric.sh' % (os.environ['USER'])
        if os.path.exists(confdir):
            if os.path.isfile(autofile) == False: 
                print "Writing '%s'" % (autofile)
                autofile = open("%s" % (autofile), 'w')
                autofile.write("[Desktop Entry]\n")
                autofile.write("Type=Application\n")
                autofile.write("Exec=/home/alex/.config/pictoric/run_pictoric.sh\n")
                autofile.write("Hidden=false\n")
                autofile.write("NoDisplay=false\n")
                autofile.write("X-GNOME-Autostart-enabled=true\n")
                autofile.write("Name[en_US]=Pictoric\n")
                autofile.write("Name=Pictoric\n")
                autofile.write("Comment[en_US]=Start Wallpaper Slideshow\n")
                autofile.write("Comment=Start Wallpaper Slideshow\n")
                autofile.close()
            if os.path.isfile(runfile) == False:
                print "Writing '%s'" % (runfile)
                runfile = open("%s" % (runfile), 'w')
                runfile.write("#!/bin/bash\n")
                runfile.write("python /opt/extras.ubuntu.com/pictoric/pictoric/PictoricBg.py")
                runfile.close()
            if os.path.isfile(configPath) == False: #Tests if config file already exists
                print "Writing '%s'" % (configPath)
                config = open("%s" % (configPath), 'w')
                config.write("%s\n" % (sourceFolder))
                config.write("%s\n" % (sourceInterval))
                config.close()
                if os.path.isfile(configPath) == True: #If exists, open for reading and future writing
                    config = open("%s" % (configPath), 'r')
                    sourceFolder = config.readline()
                    sourceInterval = config.readline()
                    config.close()
        else:
            os.makedirs(confdir)
            print "Writing '%s'" % (configPath)
            config = open("%s" % (configPath), 'w')
            config.write("%s\n" % (sourceFolder))
            config.write("%s\n" % (sourceInterval))
            config.close()
            print "Writing '%s'" % (runfile)
            runfile = open("%s" % (runfile), 'w')
            runfile.write("#!/bin/bash\n")
            runfile.write("python /opt/extras.ubuntu.com/pictoric/pictoric/PictoricBg.py")
            runfile.close()            
            if os.path.isfile(autofile) == False:
                print "Writing '%s'" % (autofile)
                autofile = open("%s" % (autofile), 'w')
                autofile.write("[Desktop Entry]\n")
                autofile.write("Type=Application\n")
                autofile.write("Exec=/home/alex/.config/pictoric/run_pictoric.sh\n")
                autofile.write("Hidden=false\n")
                autofile.write("NoDisplay=false\n")
                autofile.write("X-GNOME-Autostart-enabled=true\n")
                autofile.write("Name[en_US]=Pictoric\n")
                autofile.write("Name=Pictoric\n")
                autofile.write("Comment[en_US]=Start Wallpaper Slideshow\n")
                autofile.write("Comment=Start Wallpaper Slideshow\n")
                autofile.close()
            
        super(PictoricWindow, self).finish_initializing(builder)

    def changer(self,dir_path,sourceInterval=defaultInterval, minute=60):
        print "Starting wallpaper slideshow with folder->'%s' and interval->%s" % (dir_path,sourceInterval)
        gsettings = Gio.Settings.new(self.SCHEMA)
        for name in os.listdir(dir_path):
            background = (os.path.join(dir_path, name))
            if name.endswith(".jpg") or name.endswith(".png") or name.endswith(".jpeg"):
                gsettings.set_string(self.KEY, "file://" + background)
                time.sleep(float(sourceInterval)*minute)
                print "Set new background '%s' in %s minute(s)!" % (background, sourceInterval)
            else:
                print "Warning: Tried setting background, but '%s' is not a image file!" % (background)
        return
        
    def button_apply(self, builder, sourceFolder=defaultDirectory,sourceInterval=defaultInterval, configPath ='/home/%s/.config/pictoric/pictoric.conf' % (os.environ['USER'])):
        print "Saving '%s'" % (configPath)
        sourceFolder = self.builder.get_object("folderChooser").get_filename()
        sourceInterval = self.builder.get_object("intervalEdit").get_text()
        if sourceInterval == '0':
            sourceInterval = 5
        config = open("%s" % (configPath), 'w')
        config.write("%s\n" % (sourceFolder))
        config.write("%s\n" % (sourceInterval))
        self.destroy()
    
        
    def button_cancel(self, builder):
        Gtk.main_quit()
        raise SystemExit(0)

    def update_folder(self, builder,sourceFolder=sourceFolder,iconStore=iconStore):
        files = 0
        files_jpg = 0
        files_png = 0
        iconStore.clear()
        sourceFolder = self.builder.get_object("folderChooser").get_filename()
        iconview = self.builder.get_object("displayView")
        iconview.set_columns(-1)
        iconview.set_model(iconStore)
        iconview.set_pixbuf_column(0)
        iconview.set_selection_mode(Gtk.SelectionMode.MULTIPLE)
        
        Status = self.builder.get_object("status")
        #sourceFolder = "/home/cole/testme_dir2"

        #see if it exists
        if os.path.exists(sourceFolder):
            print "Directory "+sourceFolder+" is valid"
        else:
        # maybe do a dialog here?
            try:
                print "Could not find directory "+sourceFolder+" attempting to create it."
                os.makedirs(sourceFolder)
                print "Directory created at "+sourceFolder
            except OSError:
                print "Could not create directory at "+sourceFolder
                raise SystemExit(0)
        
        for name in os.listdir(sourceFolder):
            filename = os.path.join(sourceFolder, name)
            if name.endswith(".jpg") or name.endswith(".png") or name.endswith(".jpeg"):
                if name.endswith(".jpg") or name.endswith(".jpeg"):
                    files_jpg = files_jpg + 1
                if name.endswith(".png"):
                    files_png = files_png + 1
                files = files + 1
                pixbuf = Pixbuf.new_from_file_at_size(filename,96,96)
                iconStore.append([pixbuf])
            else:
                print "Warning: '%s' is not a image file!" % (filename)
        if files == 0:
            Status.push(1,"No images found in %s" % (sourceFolder))
        else:
            Status.push(1,"%s images found (%s .jpg, %s .png)" % (files, files_jpg, files_png))

        print "+++++++++"
    

    def change_interval(self, builder):
        return
        


